'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _lodash = require('lodash.merge');

var _lodash2 = _interopRequireDefault(_lodash);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

var Pagination = function Pagination(_ref) {
  var page = _ref.page,
      pageCount = _ref.pageCount,
      pageSkip = _ref.pageSkip,
      showFirst = _ref.showFirst,
      showLast = _ref.showLast,
      showEllipses = _ref.showEllipses,
      firstText = _ref.firstText,
      lastText = _ref.lastText,
      prevText = _ref.prevText,
      nextText = _ref.nextText,
      maintainSkipWidth = _ref.maintainSkipWidth,
      onClick = _ref.onClick,
      style = _ref.style;


  var handleNext = function handleNext() {
    var pageNumber = page + 1;
    if (pageNumber > pageCount) return;
    onClick(pageNumber);
  };

  var handlePrev = function handlePrev() {
    var pageNumber = page - 1;
    if (pageNumber < 1) return;
    onClick(pageNumber);
  };

  var handleSkip = function handleSkip(pageNumber) {
    if (page === pageNumber) return;
    onClick(pageNumber);
  };

  var handleFirst = function handleFirst() {
    onClick(1);
  };

  var handleLast = function handleLast() {
    onClick(pageCount);
  };

  var styles = (0, _lodash2.default)({}, Pagination.defaultStyles, style);

  var First = function First() {
    if (!showFirst) return null;
    return _react2.default.createElement(
      'li',
      { style: page <= 1 ? styles.pageControl.disabled : styles.pageControl.base, onClick: handleFirst },
      firstText
    );
  };

  var Prev = function Prev() {
    return _react2.default.createElement(
      'li',
      { style: page <= 1 ? styles.pageControl.disabled : styles.pageControl.base, onClick: handlePrev },
      prevText
    );
  };

  var LeftEllipses = function LeftEllipses() {

    if (!showEllipses) return null;
    if (pageSkip * 2 >= pageCount) return null;
    if (page <= pageSkip + 1) return null;

    return _react2.default.createElement(
      'li',
      {
        style: styles.ellipses,
        onClick: function onClick() {
          return handleSkip(1);
        } },
      '1 ...'
    );
  };

  var RightEllipses = function RightEllipses() {
    if (!showEllipses) return null;
    if (pageSkip * 2 >= pageCount) return null;
    if (page >= pageCount - pageSkip) return null;

    return _react2.default.createElement(
      'li',
      {
        onClick: function onClick() {
          return handleSkip(pageCount);
        },
        style: styles.ellipses },
      '... ',
      pageCount
    );
  };

  var buildPages = function buildPages() {
    if (pageSkip <= 0) return null;

    var frontSkip = maintainSkipWidth ? pageCount - page < pageSkip ? pageSkip - (pageCount - page) + pageSkip : pageSkip : pageSkip;

    var backSkip = maintainSkipWidth ? page <= pageSkip ? pageSkip + (pageSkip - page + 1) : pageSkip : pageSkip;

    var front = new Array(frontSkip).fill(page).reduce(function (arr, next, index) {
      next = next - index - 1;
      if (next < 1) return arr;
      return [next].concat(_toConsumableArray(arr));
    }, []);

    var back = new Array(backSkip).fill(page).reduce(function (arr, next, index) {
      next = next + index + 1;
      if (next > pageCount) return arr;
      return [].concat(_toConsumableArray(arr), [next]);
    }, []);

    return [].concat(_toConsumableArray(front), [page], _toConsumableArray(back)).map(function (pageNumber) {
      return _react2.default.createElement(
        'li',
        {
          key: pageNumber,
          style: page !== pageNumber ? styles.pageNumber : styles.selected,
          onClick: function onClick() {
            return handleSkip(pageNumber);
          }
        },
        pageNumber
      );
    });
  };

  var Next = function Next() {
    return _react2.default.createElement(
      'li',
      { style: page >= pageCount ? styles.pageControl.disabled : styles.pageControl.base, onClick: handleNext },
      nextText
    );
  };

  var Last = function Last() {
    if (!showLast) return null;
    return _react2.default.createElement(
      'li',
      { style: page >= pageCount ? styles.pageControl.disabled : styles.pageControl.base, onClick: handleLast },
      lastText
    );
  };

  return _react2.default.createElement(
    'ul',
    { style: styles.ul },
    _react2.default.createElement(First, null),
    _react2.default.createElement(Prev, null),
    _react2.default.createElement(LeftEllipses, null),
    buildPages(),
    _react2.default.createElement(RightEllipses, null),
    _react2.default.createElement(Next, null),
    _react2.default.createElement(Last, null)
  );
};

Pagination.propTypes = {
  page: _propTypes2.default.number.isRequired,
  pageCount: _propTypes2.default.number.isRequired,
  pageSkip: _propTypes2.default.number,
  showFirst: _propTypes2.default.bool,
  showLast: _propTypes2.default.bool,
  showEllipses: _propTypes2.default.bool,
  firstText: _propTypes2.default.node,
  lastText: _propTypes2.default.node,
  nextText: _propTypes2.default.node,
  prevText: _propTypes2.default.node,
  maintainSkipWidth: _propTypes2.default.bool,
  onClick: _propTypes2.default.func.isRequired,
  style: _propTypes2.default.object
};

Pagination.defaultProps = {
  page: 1,
  pageCount: 1,
  showEllipses: false,
  showFirst: false,
  showLast: false,
  firstText: 'First',
  lastText: 'Last',
  nextText: 'Next',
  prevText: 'Prev',
  style: {}
};

Pagination.defaultStyles = {
  ul: {
    display: 'flex',
    listStyleType: 'none',
    margin: 0,
    padding: 0
  },
  pageControl: {
    base: {
      backgroundColor: '#ffffff',
      color: '#000000',
      borderRadius: 2,
      margin: '0 3px',
      padding: 7,
      cursor: 'pointer'
    },
    disabled: {
      borderRadius: 2,
      margin: '0 3px',
      padding: 7,
      cursor: 'default'
    }
  },
  pageNumber: {
    margin: '0 3px',
    padding: 7,
    cursor: 'pointer',
    fontSize: 16,
    fontFamily: 'Helvetica Neue, Helvetica, Arial, sans-serif'
  },
  selected: {
    margin: '0 3px',
    padding: 7,
    borderRadius: 2,
    backgroundColor: '#ffffff',
    color: '#000000',
    fontSize: 16,
    fontFamily: 'Helvetica Neue, Helvetica, Arial, sans-serif'
  },
  ellipses: {
    margin: 0,
    padding: 7,
    whiteSpace: 'nowrap',
    cursor: 'pointer',
    fontSize: 16,
    fontFamily: 'Helvetica Neue, Helvetica, Arial, sans-serif'
  }
};

exports.default = Pagination;