'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _TextFieldInput = require('./TextFieldInput');

var _TextFieldInput2 = _interopRequireDefault(_TextFieldInput);

var _TextFieldExtension = require('./TextFieldExtension');

var _TextFieldExtension2 = _interopRequireDefault(_TextFieldExtension);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _lodash = require('lodash.merge');

var _lodash2 = _interopRequireDefault(_lodash);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var TextField = function TextField(props) {

  var styles = (0, _lodash2.default)({}, TextField.defaultStyles, {
    // appendExtension
    wrapper: {
      base: {
        flexDirection: props.appendExtension === 'right' ? 'row' : 'row-reverse'
      }
    },
    input: {
      base: {
        // icon placement
        paddingLeft: props.leftIcon ? 40 : TextField.defaultStyles.input.base.paddingLeft,
        paddingRight: props.canClear ? 40 : TextField.defaultStyles.input.base.paddingRight,
        // border on extension
        borderRadius: props.extension ? props.appendExtension === 'right' ? '2px 0 0 2px' : '0 2px 2px 0' : 2
      }
    }
  },
  // user overwrite
  props.style

  // change extension location
  );if (props.extension) {
    (0, _lodash2.default)(styles.extension.base, styles.extension[props.appendExtension]);
  }

  return _react2.default.createElement(
    'span',
    { style: styles.wrapper.base },
    _react2.default.createElement(_TextFieldInput2.default, _extends({}, props, { style: styles })),
    _react2.default.createElement(_TextFieldExtension2.default, _extends({}, props, { style: styles.extension }))
  );
};

TextField.propTypes = {
  placeholder: _propTypes2.default.string,
  name: _propTypes2.default.string,
  role: _propTypes2.default.string,
  tabIndex: _propTypes2.default.number,
  id: _propTypes2.default.string,
  element: _propTypes2.default.oneOf(['input', 'textarea']),
  value: _propTypes2.default.oneOfType([_propTypes2.default.string, _propTypes2.default.number]),
  validators: _propTypes2.default.arrayOf(_propTypes2.default.shape({
    name: _propTypes2.default.string,
    rule: _propTypes2.default.func.isRequired,
    errorMessage: _propTypes2.default.string
  })),
  isDisabled: _propTypes2.default.bool,
  autoFocus: _propTypes2.default.bool,
  canClear: _propTypes2.default.bool,
  leftIcon: _propTypes2.default.oneOfType([_propTypes2.default.bool, _propTypes2.default.element]),
  clearIcon: _propTypes2.default.oneOfType([_propTypes2.default.bool, _propTypes2.default.element]),
  extension: _propTypes2.default.any, //TODO: fix these types - dropdown, button, string only
  appendExtension: _propTypes2.default.oneOf(['left', 'right']),
  onClear: _propTypes2.default.func,
  onChange: _propTypes2.default.func,
  onFocus: _propTypes2.default.func,
  onBlur: _propTypes2.default.func,
  onEnterKey: _propTypes2.default.func,
  validateOnChange: _propTypes2.default.bool,
  validateOnMount: _propTypes2.default.bool,
  initialCursorPosition: _propTypes2.default.number,
  shouldAllowTab: _propTypes2.default.bool
};

TextField.defaultProps = {
  element: 'input',
  role: 'textbox',
  appendExtension: 'right',
  isDisabled: false,
  value: undefined,
  onClear: function onClear() {},
  onChange: function onChange() {},
  validateOnChange: false,
  validateOnMount: false,
  initialCursorPosition: 0,
  shouldAllowTab: false
};

TextField.defaultStyles = {
  wrapper: {
    base: {
      display: 'flex',
      flexWrap: 'nowrap',
      width: '100%'
    }
  },
  inputContainer: {
    base: {
      position: 'relative',
      flexGrow: 1,
      display: 'flex',
      flexWrap: 'nowrap',
      width: '100%'
    }
  },
  input: {
    base: {
      width: '100%',
      paddingTop: 10,
      paddingRight: 15,
      paddingBottom: 10,
      paddingLeft: 15,
      borderRadius: 2,
      border: '1px solid',
      borderColor: '#979797',
      boxSizing: 'border-box',
      backgroundColor: 'transparent',
      color: '#000000',
      fontFamily: 'Lato-Light',
      fontSize: 18,
      transition: 'all 0.4s',
      outline: 'none',
      minWidth: 200,
      resize: 'none'
    },
    hovered: {},
    focused: {
      borderColor: '#09D8B7'
    },
    error: {
      borderColor: '#F25B5B'
    },
    disabled: {
      borderColor: '#b5b5b5',
      color: '#b5b5b5'
    }
  },
  errorMessage: {
    base: {
      bottom: -17,
      position: 'absolute',
      color: '#F25B5B',
      fontSize: 14,
      padding: 0,
      margin: 0,
      boxSizing: 'border-box'
    }
  },
  leftIcon: {
    base: {
      color: '#b5b5b5',
      position: 'absolute',
      left: 10,
      alignSelf: 'center',
      opacity: 0.5
    }
  },
  clearIcon: {
    base: {
      color: '#b5b5b5',
      position: 'absolute',
      right: 10,
      alignSelf: 'center',
      cursor: 'pointer'
    }
  },
  extension: {
    base: {
      display: 'flex',
      flexDirection: 'center',
      alignItems: 'center',
      backgroundColor: '#b5b5b5',
      boxSizing: 'border-box',
      padding: 10,
      color: 'white'
    },
    left: {
      borderRadius: '2px 0 0 2px'
    },
    right: {
      borderRadius: '0 2px 2px 0'
    }
  }
};

exports.default = TextField;