'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

exports.default = withMediaQueries;

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _lodash = require('lodash.invertby');

var _lodash2 = _interopRequireDefault(_lodash);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var Size = {
  xs: 0,
  sm: 1,
  md: 2,
  lg: 3,
  xl: 4,
  xxl: 5
};

function withMediaQueries(WrappedComponent) {
  var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};


  var defaultBreakPoints = {
    xxl: Infinity, // xxl - greater than 1440
    xl: options.xl || 1440, // extra large  - between 1440 & 1030
    lg: options.lg || 1030, // large - between 1030 & 991
    md: options.md || 991, // medium - between 991 & 767
    sm: options.sm || 768, // small - between 767 & 414
    xs: options.xs || 414 // extra small - below 414
  };

  var breakPoints = _extends({}, defaultBreakPoints, options);

  var pointsArray = Object.keys(breakPoints).map(function (key, i) {
    var Dict = (0, _lodash2.default)(Size, function (value) {
      return parseInt(value);
    });
    return breakPoints[Dict[i]];
  });

  function setWidthRanges(size) {

    var index = Size[size];
    var prevIndex = Size[size] - 1;

    var maxWidth = index === 5 ? Infinity : pointsArray[index];
    var minWidth = prevIndex < 0 ? 0 : pointsArray[prevIndex] + 1;

    return { maxWidth: maxWidth, minWidth: minWidth };
  }

  var WithMediaQueries = function (_React$Component) {
    _inherits(WithMediaQueries, _React$Component);

    function WithMediaQueries() {
      var _ref;

      var _temp, _this, _ret;

      _classCallCheck(this, WithMediaQueries);

      for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
        args[_key] = arguments[_key];
      }

      return _ret = (_temp = (_this = _possibleConstructorReturn(this, (_ref = WithMediaQueries.__proto__ || Object.getPrototypeOf(WithMediaQueries)).call.apply(_ref, [this].concat(args))), _this), _this.state = {
        orientation: '',
        mediaQuery: { size: '', minWidth: 0, maxWidth: 0 }
      }, _this.handleSizeChange = function (size, e) {
        size = size === 'xl' ? e.matches ? 'xl' : 'xxl' : size;
        size = size === 'lg' ? e.matches ? 'lg' : 'xl' : size;
        size = size === 'md' ? e.matches ? 'md' : 'lg' : size;
        size = size === 'sm' ? e.matches ? 'sm' : 'md' : size;
        size = size === 'xs' ? e.matches ? 'xs' : 'sm' : size;

        _this.setState({ mediaQuery: _extends({ sizeName: size, sizeValue: Size[size] }, setWidthRanges(size)) });
      }, _this.handleOrientationChange = function (e) {
        _this.setState({ orientation: e.matches ? 'portrait' : 'landscape' });
      }, _temp), _possibleConstructorReturn(_this, _ret);
    }

    _createClass(WithMediaQueries, [{
      key: 'componentWillMount',
      value: function componentWillMount() {
        // break-points
        var mediaQuery = {};
        for (var size in breakPoints) {
          this[size] = window.matchMedia('(max-width: ' + breakPoints[size] + 'px)');
          this[size].addListener(this.handleSizeChange.bind(null, size));

          if (this[size].matches) mediaQuery = _extends({
            sizeName: size,
            sizeValue: Size[size]
          }, setWidthRanges(size));
        }

        // media query undefined
        if (Object.keys(mediaQuery).length === 0) mediaQuery = _extends({
          sizeName: 'xxl',
          sizeValue: Size['xxl']
        }, setWidthRanges('xxl'));

        //orientation
        this.orientation = window.matchMedia("(orientation: portrait)");
        this.orientation.addListener(this.handleOrientationChange);
        var orientation = this.orientation.matches ? 'portrait' : 'landscape';

        this.setState({ orientation: orientation, mediaQuery: mediaQuery });
      }
    }, {
      key: 'componentWillUnmount',
      value: function componentWillUnmount() {

        // break-points
        for (var size in breakPoints) {
          this[size].removeListener(this.handleSizeChange);
        }

        // orientation
        this.orientation.removeListener(this.handleOrientationChange);
      }
    }, {
      key: 'render',
      value: function render() {
        return _react2.default.createElement(WrappedComponent, _extends({}, this.props, this.state, {
          breakPoints: breakPoints }));
      }
    }]);

    return WithMediaQueries;
  }(_react2.default.Component);

  return WithMediaQueries;
}